Test Report

# Summary

Started | 2025-12-19 15:34:42
Ended | 2025-12-19 15:34:47
Duration | 0:00:05.084579
Total run time | 0:00:03.629992

19 passed

# Tests

## tests/test_cli_parser.py 9 0:00:01.016010

### PASSED Test_CLIParser::test_clean_snow_grain_size_retrieval 0:00:00.261038

Started | 2025-12-19 15:34:44
Ended | 2025-12-19 15:34:44
Duration | 0:00:00.261038
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    Using default aerosol optical thickness (AOT=0.05) for Antarctica.
    Using default angström exponent (AE=1.3) for Antarctica.
    Writing GeoArray of size (3, 2, 10) to /tmp/tmpjq670chq/output_clean.bsq.
    Writing GeoArray of size (3, 2, 224) to /tmp/tmpjq670chq/output_3_albedo.bsq.
    Writing GeoArray of size (3, 2, 224) to /tmp/tmpjq670chq/output_4_BOAR.bsq.
    Writing GeoArray of size (3, 2, 224) to /tmp/tmpjq670chq/output_5_PA.bsq.
    Writing GeoArray of size (3, 2, 6) to /tmp/tmpjq670chq/output_6_BBA.bsq.

#### Teardown

### PASSED Test_CLIParser::test_main 0:00:00.229204

Started | 2025-12-19 15:34:44
Ended | 2025-12-19 15:34:44
Duration | 0:00:00.229204
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    Using default aerosol optical thickness (AOT=0.05) for Antarctica.
    Using default angström exponent (AE=1.3) for Antarctica.
    Writing GeoArray of size (3, 2, 10) to /tmp/tmpiqqiuk8b/output_clean.bsq.
    Writing GeoArray of size (3, 2, 224) to /tmp/tmpiqqiuk8b/output_3_albedo.bsq.
    Writing GeoArray of size (3, 2, 224) to /tmp/tmpiqqiuk8b/output_4_BOAR.bsq.
    Writing GeoArray of size (3, 2, 224) to /tmp/tmpiqqiuk8b/output_5_PA.bsq.
    Writing GeoArray of size (3, 2, 6) to /tmp/tmpiqqiuk8b/output_6_BBA.bsq.

#### Teardown

### PASSED Test_CLIParser::test_main_no_args 0:00:00.012851

Started | 2025-12-19 15:34:44
Ended | 2025-12-19 15:34:44
Duration | 0:00:00.012851
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_no_args 0:00:00.009240

Started | 2025-12-19 15:34:44
Ended | 2025-12-19 15:34:44
Duration | 0:00:00.009240
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_param_acceptance 0:00:00.010108

Started | 2025-12-19 15:34:44
Ended | 2025-12-19 15:34:44
Duration | 0:00:00.010108
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_polluted_snow_albedo_impurities_retrieval 0:00:00.230233

Started | 2025-12-19 15:34:44
Ended | 2025-12-19 15:34:44
Duration | 0:00:00.230233
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    Using default aerosol optical thickness (AOT=0.05) for Antarctica.
    Using default angström exponent (AE=1.3) for Antarctica.
    Writing GeoArray of size (3, 2, 5) to /tmp/tmp5sinrzff/out.bsq.
    Writing GeoArray of size (3, 2, 224) to /tmp/tmp5sinrzff/output_impurity_rs.bsq.
    Writing GeoArray of size (3, 2, 224) to /tmp/tmp5sinrzff/output_impurity_rp.bsq.
    Writing GeoArray of size (3, 2, 224) to /tmp/tmp5sinrzff/output_imp_bba_plane.bsq.

#### Teardown

### PASSED Test_CLIParser::test_polluted_snow_broadband_albedo_retrieval 0:00:00.239176

Started | 2025-12-19 15:34:44
Ended | 2025-12-19 15:34:45
Duration | 0:00:00.239176
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    Using default aerosol optical thickness (AOT=0.05) for Antarctica.
    Using default angström exponent (AE=1.3) for Antarctica.
    Writing GeoArray of size (3, 2, 10) to /tmp/tmp22syttx4/output_clean.bsq.
    Writing GeoArray of size (3, 2, 5) to /tmp/tmp22syttx4/out.bsq.
    Writing GeoArray of size (3, 2, 15) to /tmp/tmp22syttx4/output_impurity.bsq.
    Writing GeoArray of size (3, 2, 6) to /tmp/tmp22syttx4/output_BBA.bsq.

#### Teardown

### PASSED Test_CLIParser::test_record_args_in_gui_test 0:00:00.014126

Started | 2025-12-19 15:34:45
Ended | 2025-12-19 15:34:45
Duration | 0:00:00.014126
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_snow_screener_thresholds_passed_correctly 0:00:00.010034

Started | 2025-12-19 15:34:45
Ended | 2025-12-19 15:34:45
Duration | 0:00:00.010034
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_io.py 6 0:00:01.711185

### PASSED TestReaderEnMAPL1C::test_create_vrt 0:00:00.953618

Started | 2025-12-19 15:34:45
Ended | 2025-12-19 15:34:46
Duration | 0:00:00.953618
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    Using default aerosol optical thickness (AOT=0.05) for Antarctica.
    Using default angström exponent (AE=1.3) for Antarctica.

#### Teardown

### PASSED TestReaderEnMAPL1C::test_to_toa_reflectance 0:00:00.167979

Started | 2025-12-19 15:34:46
Ended | 2025-12-19 15:34:46
Duration | 0:00:00.167979
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    Using default aerosol optical thickness (AOT=0.05) for Antarctica.
    Using default angström exponent (AE=1.3) for Antarctica.

#### Teardown

### PASSED TestReaderEnMAPL1C::test_to_toa_reflectance_with_ae 0:00:00.164917

Started | 2025-12-19 15:34:46
Ended | 2025-12-19 15:34:46
Duration | 0:00:00.164917
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    Using default aerosol optical thickness (AOT=0.05) for Antarctica.

#### Teardown

### PASSED TestReaderEnMAPL1C::test_to_toa_reflectance_with_aot 0:00:00.167115

Started | 2025-12-19 15:34:46
Ended | 2025-12-19 15:34:46
Duration | 0:00:00.167115
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    Using default angström exponent (AE=1.3) for Antarctica.

#### Teardown

### PASSED TestReaderEnMAPL1C::test_to_toa_reflectance_with_band_list 0:00:00.129756

Started | 2025-12-19 15:34:46
Ended | 2025-12-19 15:34:46
Duration | 0:00:00.129756
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    Using default aerosol optical thickness (AOT=0.05) for Antarctica.
    Using default angström exponent (AE=1.3) for Antarctica.

#### Teardown

### PASSED TestReaderEnMAPL1C::test_to_toa_reflectance_with_band_list_single_band 0:00:00.127800

Started | 2025-12-19 15:34:46
Ended | 2025-12-19 15:34:46
Duration | 0:00:00.127800
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    Using default aerosol optical thickness (AOT=0.05) for Antarctica.
    Using default angström exponent (AE=1.3) for Antarctica.

#### Teardown

## tests/test_retrieval.py 4 0:00:00.902797

### PASSED TestRetrieval::test_parameter_snow_pixels_only 0:00:00.338446

Started | 2025-12-19 15:34:46
Ended | 2025-12-19 15:34:47
Duration | 0:00:00.338446
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    Using default aerosol optical thickness (AOT=0.05) for Antarctica.
    Using default angström exponent (AE=1.3) for Antarctica.
    The output directory /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/tests/data/output does not exist. Creating it now.
    Using default aerosol optical thickness (AOT=0.05) for Antarctica.
    Using default angström exponent (AE=1.3) for Antarctica.

#### Teardown

### PASSED TestRetrieval::test_run_clean_snow_grain_size_retrieval 0:00:00.175260

Started | 2025-12-19 15:34:47
Ended | 2025-12-19 15:34:47
Duration | 0:00:00.175260
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    Using default aerosol optical thickness (AOT=0.05) for Antarctica.
    Using default angström exponent (AE=1.3) for Antarctica.
    Writing GeoArray of size (3, 2, 10) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/tests/data/output/output_clean.bsq.

#### Teardown

### PASSED TestRetrieval::test_run_polluted_snow_albedo_impurities_retrieval 0:00:00.189353

Started | 2025-12-19 15:34:47
Ended | 2025-12-19 15:34:47
Duration | 0:00:00.189353
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    Using default aerosol optical thickness (AOT=0.05) for Antarctica.
    Using default angström exponent (AE=1.3) for Antarctica.
    Writing GeoArray of size (3, 2, 5) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/tests/data/output/out.bsq.
    Writing GeoArray of size (3, 2, 224) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/tests/data/output/output_impurity_rs.bsq.
    Writing GeoArray of size (3, 2, 224) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/tests/data/output/output_impurity_rp.bsq.
    Writing GeoArray of size (3, 2, 224) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/tests/data/output/output_imp_bba_plane.bsq.

#### Teardown

### PASSED TestRetrieval::test_run_polluted_snow_broadband_albedo_retrieval 0:00:00.199737

Started | 2025-12-19 15:34:47
Ended | 2025-12-19 15:34:47
Duration | 0:00:00.199737
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    Using default aerosol optical thickness (AOT=0.05) for Antarctica.
    Using default angström exponent (AE=1.3) for Antarctica.
    Writing GeoArray of size (3, 2, 10) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/tests/data/output/output_clean.bsq.
    Writing GeoArray of size (3, 2, 5) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/tests/data/output/out.bsq.
    Writing GeoArray of size (3, 2, 15) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/tests/data/output/output_impurity.bsq.
    Writing GeoArray of size (3, 2, 6) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/enfrosp/tests/data/output/output_BBA.bsq.
    0.19124484062194824

#### Teardown